tags 552832 + patch pending
thanks

Dear maintainer,

I've prepared an NMU for screader (versioned as 1.8-5.1) and
uploaded it to DELAYED/2. Please feel free to tell me if I
should delay it longer.

Regards.

-- 
Mehdi Dogguy
diff -u screader-1.8/debian/changelog screader-1.8/debian/changelog
--- screader-1.8/debian/changelog
+++ screader-1.8/debian/changelog
@@ -1,3 +1,11 @@
+screader (1.8-5.1) unstable; urgency=low
+
+  * Non-maintainer upload.
+  * tts.c: renamed getline to local_getline to avoid a conflict with the
+    function defined in stdio.h (Patch from Ubuntu) (Closes: #552832)
+
+ -- Mehdi Dogguy <[email protected]>  Fri, 05 Feb 2010 21:55:38 +0100
+
 screader (1.8-5) unstable; urgency=low
 
   * Rebuild to fix terminfo location (Closes: Bug#334183)
@@ -32 +39,0 @@
-

Reply via email to
diff -u screader-1.8/tts.c screader-1.8/tts.c
--- screader-1.8/tts.c
+++ screader-1.8/tts.c
@@ -67,10 +67,10 @@
 } /* beep */
 
 /*********************************************************************\
 * getline - gets a line from file descriptor and returns its pointer. *
 \*********************************************************************/
 
-char *getline (FILE *r)
+char *local_getline (FILE *r)
 {
    static char hulp[100];
    int i = -1;
@@ -83,7 +83,7 @@
    } while (hulp[i] != '\n');
    hulp[i] = 0;
    return (char *) hulp;
-} /* getline */
+} /* local_getline */
 
 /*************************************************************\
 * Get_TTS_command - Get the TTS-command from the config-file. *
@@ -113,7 +113,7 @@
          rewind (r);
          tts_number = x = 0;
       } // if
-      strcpy (tts_command, getline (r));
+      strcpy (tts_command, local_getline (r));
       if (*tts_command == 0 || *tts_command == '#')
       {
          x--;
@@ -67,10 +67,10 @@
 
 /*********************************************************************\
-* getline - gets a line from file descriptor and returns its pointer. *
+* local_getline - gets a line from file descriptor and returns its pointer. *
 \*********************************************************************/
 